pymermaid vs mermaid.js Comparison

# pymermaid vs mermaid.js Visual Comparison

Diagrams compared: 110

Average SSIM: 0.2554

Min SSIM: 0.0001

Max SSIM: 0.6592

Diagram | SSIM | Pixel Diff % | Rating
--- | --- | --- | ---
sequence/activations | 0.0001 | 99.97% | Needs Work
gitgraph/complex | 0.0045 | 99.91% | Needs Work
gitgraph/cherry_pick | 0.0062 | 99.97% | Needs Work
gitgraph/branching | 0.0075 | 99.96% | Needs Work
mindmap/deep_tree | 0.0077 | 99.7% | Needs Work
sequence/complex | 0.0151 | 97.48% | Needs Work
gitgraph/basic | 0.0155 | 100.0% | Needs Work
mindmap/basic | 0.0236 | 99.88% | Needs Work
sequence/loops | 0.0292 | 95.9% | Needs Work
flowchart/elt_bigquery | 0.0294 | 93.51% | Needs Work
flowchart/etl_postgres | 0.031 | 96.14% | Needs Work
mindmap/single_root | 0.0518 | 98.15% | Needs Work
sequence/arrows | 0.0529 | 93.98% | Needs Work
sequence/basic | 0.0571 | 92.68% | Needs Work
sequence/flink_late_upsert | 0.0713 | 96.32% | Needs Work
gantt/single_section | 0.093 | 88.91% | Needs Work
scale/medium | 0.1043 | 87.2% | Needs Work
sequence/flink_late_event | 0.1066 | 96.18% | Needs Work
sequence/notes | 0.107 | 93.96% | Needs Work
mindmap/shapes | 0.1188 | 96.81% | Needs Work
class/inheritance | 0.1222 | 76.4% | Needs Work
state/complex | 0.124 | 82.16% | Needs Work
state/choice | 0.1299 | 82.44% | Needs Work
flowchart/registration | 0.1304 | 80.99% | Needs Work
pie/many_slices | 0.1349 | 98.41% | Needs Work
flowchart/api_request | 0.1441 | 82.34% | Needs Work
class/relationships | 0.1451 | 64.06% | Needs Work
class/annotations | 0.1462 | 72.75% | Needs Work
flowchart/ci_pipeline | 0.1494 | 87.67% | Needs Work
state/basic | 0.151 | 81.76% | Needs Work
gantt/basic | 0.1564 | 82.71% | Needs Work
class/all_relationships | 0.1569 | 63.72% | Needs Work
pie/show_data | 0.1598 | 98.48% | Needs Work
flowchart/emoji_workflow | 0.1624 | 78.34% | Needs Work
flowchart/etl_simple | 0.1653 | 73.64% | Needs Work
pie/basic | 0.1681 | 98.28% | Needs Work
pie/no_title | 0.1697 | 98.67% | Needs Work
flowchart/debug_loop | 0.1705 | 77.26% | Needs Work
er/dashed_lines | 0.1712 | 73.07% | Needs Work
gantt/modifiers | 0.1713 | 85.92% | Needs Work
flowchart/coffee_machine | 0.1719 | 75.15% | Needs Work
class/basic | 0.1752 | 71.24% | Needs Work
basic/fan_in | 0.1807 | 76.82% | Needs Work
basic/fan_out | 0.1827 | 76.89% | Needs Work
pie/single_slice | 0.185 | 98.65% | Needs Work
er/complex | 0.1861 | 71.73% | Needs Work
flowchart/emoji | 0.19 | 74.74% | Needs Work
shapes/mixed_shapes | 0.1916 | 76.88% | Needs Work
scale/large | 0.1932 | 78.13% | Needs Work
styling/mixed_styled_unstyled | 0.2004 | 87.55% | Needs Work
gantt/no_title | 0.2027 | 83.02% | Needs Work
shapes/parallelogram_alt | 0.2208 | 72.05% | Needs Work
shapes/diamond | 0.228 | 73.91% | Needs Work
basic/self_loop | 0.2341 | 77.21% | Needs Work
er/all_cardinalities | 0.2355 | 63.2% | Needs Work
flowchart/icons | 0.2362 | 71.19% | Needs Work
basic/diamond | 0.2369 | 74.54% | Needs Work
shapes/parallelogram | 0.2401 | 70.76% | Needs Work
class/cardinality | 0.2494 | 59.25% | Needs Work
edges/labeled_edges | 0.259 | 67.71% | Needs Work
class/interface_realization | 0.2659 | 60.71% | Needs Work
shapes/hexagon | 0.2674 | 67.91% | Needs Work
class/complex | 0.2727 | 62.94% | Needs Work
er/basic | 0.2752 | 68.32% | Needs Work
shapes/trapezoid | 0.2786 | 67.14% | Needs Work
shapes/subroutine | 0.2791 | 65.49% | Needs Work
shapes/trapezoid_alt | 0.2918 | 66.98% | Needs Work
state/fork_join | 0.2942 | 92.31% | Needs Work
er/attributes | 0.2959 | 61.02% | Needs Work
shapes/stadium | 0.2982 | 64.13% | Needs Work
state/nested | 0.3015 | 86.33% | Needs Work
direction/rl | 0.3042 | 65.08% | Needs Work
direction/lr | 0.3047 | 65.01% | Needs Work
shapes/double_circle | 0.3283 | 61.02% | Needs Work
shapes/circle | 0.3336 | 63.88% | Needs Work
styling/classdef_multiple | 0.3416 | 99.5% | Needs Work
shapes/cylinder | 0.3485 | 59.51% | Needs Work
text/quoted_labels | 0.3584 | 58.83% | Needs Work
shapes/rect | 0.371 | 59.3% | Needs Work
shapes/rounded | 0.3769 | 57.73% | Needs Work
basic/parallel_paths | 0.3791 | 59.33% | Needs Work
text/multiline | 0.3849 | 57.94% | Needs Work
basic/linear_chain | 0.3971 | 59.27% | Needs Work
text/special_chars | 0.4016 | 55.02% | Needs Work
styling/classdef_single | 0.4058 | 78.71% | Needs Work
styling/inline_style | 0.4122 | 57.59% | Needs Work
text/long_text | 0.4132 | 45.51% | Needs Work
edges/invisible | 0.415 | 57.65% | Needs Work
edges/open_link | 0.4151 | 57.65% | Needs Work
edges/cross_endpoint | 0.4157 | 57.53% | Needs Work
direction/tb | 0.4162 | 57.45% | Needs Work
direction/td | 0.4162 | 57.45% | Needs Work
edges/arrow | 0.4162 | 57.45% | Needs Work
scale/small | 0.4162 | 57.45% | Needs Work
edges/dotted | 0.4163 | 57.45% | Needs Work
direction/bt | 0.417 | 57.4% | Needs Work
styling/default_class | 0.4188 | 97.6% | Needs Work
edges/circle_endpoint | 0.4193 | 57.11% | Needs Work
edges/thick | 0.4206 | 56.56% | Needs Work
text/short_text | 0.4327 | 56.1% | Needs Work
basic/two_nodes | 0.4468 | 54.93% | Needs Work
class/members | 0.4502 | 41.98% | Needs Work
subgraphs/subgraph_with_title | 0.5042 | 74.43% | Needs Work
class/many_members | 0.5045 | 37.49% | Needs Work
subgraphs/cross_boundary_edges | 0.5119 | 75.52% | Needs Work
basic/single_node | 0.5129 | 48.4% | Needs Work
subgraphs/single_subgraph | 0.6199 | 49.76% | OK
subgraphs/sibling_subgraphs | 0.6436 | 45.81% | OK
subgraphs/nested_subgraphs | 0.6584 | 42.39% | OK
subgraphs/subgraph_direction | 0.6592 | 45.71% | OK

sequence/activations (SSIM: 0.0001)
pymermaid
mermaid.js (mmdc)
Diff
gitgraph/complex (SSIM: 0.0045)
pymermaid
mermaid.js (mmdc)
Diff
gitgraph/cherry_pick (SSIM: 0.0062)
pymermaid
mermaid.js (mmdc)
Diff
gitgraph/branching (SSIM: 0.0075)
pymermaid
mermaid.js (mmdc)
Diff
mindmap/deep_tree (SSIM: 0.0077)
pymermaid
mermaid.js (mmdc)
Diff
sequence/complex (SSIM: 0.0151)
pymermaid
mermaid.js (mmdc)
Diff
gitgraph/basic (SSIM: 0.0155)
pymermaid
mermaid.js (mmdc)
Diff
mindmap/basic (SSIM: 0.0236)
pymermaid
mermaid.js (mmdc)
Diff
sequence/loops (SSIM: 0.0292)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/elt_bigquery (SSIM: 0.0294)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/etl_postgres (SSIM: 0.031)
pymermaid
mermaid.js (mmdc)
Diff
mindmap/single_root (SSIM: 0.0518)
pymermaid
mermaid.js (mmdc)
Diff
sequence/arrows (SSIM: 0.0529)
pymermaid
mermaid.js (mmdc)
Diff
sequence/basic (SSIM: 0.0571)
pymermaid
mermaid.js (mmdc)
Diff
sequence/flink_late_upsert (SSIM: 0.0713)
pymermaid
mermaid.js (mmdc)
Diff
gantt/single_section (SSIM: 0.093)
pymermaid
mermaid.js (mmdc)
Diff
scale/medium (SSIM: 0.1043)
pymermaid
mermaid.js (mmdc)
Diff
sequence/flink_late_event (SSIM: 0.1066)
pymermaid
mermaid.js (mmdc)
Diff
sequence/notes (SSIM: 0.107)
pymermaid
mermaid.js (mmdc)
Diff
mindmap/shapes (SSIM: 0.1188)
pymermaid
mermaid.js (mmdc)
Diff
class/inheritance (SSIM: 0.1222)
pymermaid
mermaid.js (mmdc)
Diff
state/complex (SSIM: 0.124)
pymermaid
mermaid.js (mmdc)
Diff
state/choice (SSIM: 0.1299)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/registration (SSIM: 0.1304)
pymermaid
mermaid.js (mmdc)
Diff
pie/many_slices (SSIM: 0.1349)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/api_request (SSIM: 0.1441)
pymermaid
mermaid.js (mmdc)
Diff
class/relationships (SSIM: 0.1451)
pymermaid
mermaid.js (mmdc)
Diff
class/annotations (SSIM: 0.1462)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/ci_pipeline (SSIM: 0.1494)
pymermaid
mermaid.js (mmdc)
Diff
state/basic (SSIM: 0.151)
pymermaid
mermaid.js (mmdc)
Diff
gantt/basic (SSIM: 0.1564)
pymermaid
mermaid.js (mmdc)
Diff
class/all_relationships (SSIM: 0.1569)
pymermaid
mermaid.js (mmdc)
Diff
pie/show_data (SSIM: 0.1598)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/emoji_workflow (SSIM: 0.1624)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/etl_simple (SSIM: 0.1653)
pymermaid
mermaid.js (mmdc)
Diff
pie/basic (SSIM: 0.1681)
pymermaid
mermaid.js (mmdc)
Diff
pie/no_title (SSIM: 0.1697)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/debug_loop (SSIM: 0.1705)
pymermaid
mermaid.js (mmdc)
Diff
er/dashed_lines (SSIM: 0.1712)
pymermaid
mermaid.js (mmdc)
Diff
gantt/modifiers (SSIM: 0.1713)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/coffee_machine (SSIM: 0.1719)
pymermaid
mermaid.js (mmdc)
Diff
class/basic (SSIM: 0.1752)
pymermaid
mermaid.js (mmdc)
Diff
basic/fan_in (SSIM: 0.1807)
pymermaid
mermaid.js (mmdc)
Diff
basic/fan_out (SSIM: 0.1827)
pymermaid
mermaid.js (mmdc)
Diff
pie/single_slice (SSIM: 0.185)
pymermaid
mermaid.js (mmdc)
Diff
er/complex (SSIM: 0.1861)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/emoji (SSIM: 0.19)
pymermaid
mermaid.js (mmdc)
Diff
shapes/mixed_shapes (SSIM: 0.1916)
pymermaid
mermaid.js (mmdc)
Diff
scale/large (SSIM: 0.1932)
pymermaid
mermaid.js (mmdc)
Diff
styling/mixed_styled_unstyled (SSIM: 0.2004)
pymermaid
mermaid.js (mmdc)
Diff
gantt/no_title (SSIM: 0.2027)
pymermaid
mermaid.js (mmdc)
Diff
shapes/parallelogram_alt (SSIM: 0.2208)
pymermaid
mermaid.js (mmdc)
Diff
shapes/diamond (SSIM: 0.228)
pymermaid
mermaid.js (mmdc)
Diff
basic/self_loop (SSIM: 0.2341)
pymermaid
mermaid.js (mmdc)
Diff
er/all_cardinalities (SSIM: 0.2355)
pymermaid
mermaid.js (mmdc)
Diff
flowchart/icons (SSIM: 0.2362)
pymermaid
mermaid.js (mmdc)
Diff
basic/diamond (SSIM: 0.2369)
pymermaid
mermaid.js (mmdc)
Diff
shapes/parallelogram (SSIM: 0.2401)
pymermaid
mermaid.js (mmdc)
Diff
class/cardinality (SSIM: 0.2494)
pymermaid
mermaid.js (mmdc)
Diff
edges/labeled_edges (SSIM: 0.259)
pymermaid
mermaid.js (mmdc)
Diff
class/interface_realization (SSIM: 0.2659)
pymermaid
mermaid.js (mmdc)
Diff
shapes/hexagon (SSIM: 0.2674)
pymermaid
mermaid.js (mmdc)
Diff
class/complex (SSIM: 0.2727)
pymermaid
mermaid.js (mmdc)
Diff
er/basic (SSIM: 0.2752)
pymermaid
mermaid.js (mmdc)
Diff
shapes/trapezoid (SSIM: 0.2786)
pymermaid
mermaid.js (mmdc)
Diff
shapes/subroutine (SSIM: 0.2791)
pymermaid
mermaid.js (mmdc)
Diff
shapes/trapezoid_alt (SSIM: 0.2918)
pymermaid
mermaid.js (mmdc)
Diff
state/fork_join (SSIM: 0.2942)
pymermaid
mermaid.js (mmdc)
Diff
er/attributes (SSIM: 0.2959)
pymermaid
mermaid.js (mmdc)
Diff
shapes/stadium (SSIM: 0.2982)
pymermaid
mermaid.js (mmdc)
Diff
state/nested (SSIM: 0.3015)
pymermaid
mermaid.js (mmdc)
Diff
direction/rl (SSIM: 0.3042)
pymermaid
mermaid.js (mmdc)
Diff
direction/lr (SSIM: 0.3047)
pymermaid
mermaid.js (mmdc)
Diff
shapes/double_circle (SSIM: 0.3283)
pymermaid
mermaid.js (mmdc)
Diff
shapes/circle (SSIM: 0.3336)
pymermaid
mermaid.js (mmdc)
Diff
styling/classdef_multiple (SSIM: 0.3416)
pymermaid
mermaid.js (mmdc)
Diff
shapes/cylinder (SSIM: 0.3485)
pymermaid
mermaid.js (mmdc)
Diff
text/quoted_labels (SSIM: 0.3584)
pymermaid
mermaid.js (mmdc)
Diff
shapes/rect (SSIM: 0.371)
pymermaid
mermaid.js (mmdc)
Diff
shapes/rounded (SSIM: 0.3769)
pymermaid
mermaid.js (mmdc)
Diff
basic/parallel_paths (SSIM: 0.3791)
pymermaid
mermaid.js (mmdc)
Diff
text/multiline (SSIM: 0.3849)
pymermaid
mermaid.js (mmdc)
Diff
basic/linear_chain (SSIM: 0.3971)
pymermaid
mermaid.js (mmdc)
Diff
text/special_chars (SSIM: 0.4016)
pymermaid
mermaid.js (mmdc)
Diff
styling/classdef_single (SSIM: 0.4058)
pymermaid
mermaid.js (mmdc)
Diff
styling/inline_style (SSIM: 0.4122)
pymermaid
mermaid.js (mmdc)
Diff
text/long_text (SSIM: 0.4132)
pymermaid
mermaid.js (mmdc)
Diff
edges/invisible (SSIM: 0.415)
pymermaid
mermaid.js (mmdc)
Diff
edges/open_link (SSIM: 0.4151)
pymermaid
mermaid.js (mmdc)
Diff
edges/cross_endpoint (SSIM: 0.4157)
pymermaid
mermaid.js (mmdc)
Diff
direction/tb (SSIM: 0.4162)
pymermaid
mermaid.js (mmdc)
Diff
direction/td (SSIM: 0.4162)
pymermaid
mermaid.js (mmdc)
Diff
edges/arrow (SSIM: 0.4162)
pymermaid
mermaid.js (mmdc)
Diff
scale/small (SSIM: 0.4162)
pymermaid
mermaid.js (mmdc)
Diff
edges/dotted (SSIM: 0.4163)
pymermaid
mermaid.js (mmdc)
Diff
direction/bt (SSIM: 0.417)
pymermaid
mermaid.js (mmdc)
Diff
styling/default_class (SSIM: 0.4188)
pymermaid
mermaid.js (mmdc)
Diff
edges/circle_endpoint (SSIM: 0.4193)
pymermaid
mermaid.js (mmdc)
Diff
edges/thick (SSIM: 0.4206)
pymermaid
mermaid.js (mmdc)
Diff
text/short_text (SSIM: 0.4327)
pymermaid
mermaid.js (mmdc)
Diff
basic/two_nodes (SSIM: 0.4468)
pymermaid
mermaid.js (mmdc)
Diff
class/members (SSIM: 0.4502)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/subgraph_with_title (SSIM: 0.5042)
pymermaid
mermaid.js (mmdc)
Diff
class/many_members (SSIM: 0.5045)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/cross_boundary_edges (SSIM: 0.5119)
pymermaid
mermaid.js (mmdc)
Diff
basic/single_node (SSIM: 0.5129)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/single_subgraph (SSIM: 0.6199)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/sibling_subgraphs (SSIM: 0.6436)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/nested_subgraphs (SSIM: 0.6584)
pymermaid
mermaid.js (mmdc)
Diff
subgraphs/subgraph_direction (SSIM: 0.6592)
pymermaid
mermaid.js (mmdc)
Diff